import wx

name = "hpyculator"

def write(filename,anything,end="\n") -> None:
    filename.write(str(anything)+end)
    filename.flush()

def write_without_flush(filename,anything,end="\n") -> None:
    filename.write(str(anything)+end)

def flush(filename) -> None:
    filename.flush()

def output(self,anything,end="\n") -> None:
    wx.CallAfter(outPutToOutPut,self,str(anything)+end)

def outPutToOutPut(self,msg:str) -> None:
    self.output.AppendText(msg)

def clearOutPut(self) -> None:
    self.output.Clear()

def setOutPut(self, msg:str) -> None:
    self.output.SetValue(msg)

def addOne(num:int) -> int:
    return num+1


from setuptools import find_packages, setup


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    # 以下为必需参数
    name='hpyculator',
    version='1.0.3',
    description='这是一个基于python的可编程计算器',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    long_description=long_description,
    url='https://github.com/pypa/sampleproject',
    author='HowieHz', # 作者名
    classifiers=[
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',

    ],
    install_requires=[
        'wxpython'
    ],
        project_urls={
        'Bug Reports': 'https://github.com/HowieHz/hpyculatorPackage/issues',
    },
)